@@ -144,8 +144,8 @@ struct _YUVCoefficients
 };
 
 /* multiplied by 65536 */
-//static const YUVCoefficients itu601_narrow = { 104597, -25675, -53279, 132201 };
-static const YUVCoefficients itu601_wide = { 74711, -25864, -38050, 133176 };
+static const YUVCoefficients itu601_narrow = { 104597, -25675, -53279, 132201 };
+//static const YUVCoefficients itu601_wide = { 74711, -25864, -38050, 133176 };
 
 static inline void
 get_uv_values (const YUVCoefficients *coeffs,
@@ -229,7 +229,7 @@ download_nv12 (guchar          *dst_data,
           int r, g, b;
           gsize xs, ys;
 
-          get_uv_values (&itu601_wide, uv_data[x / X_SUB * 2 + U], uv_data[x / X_SUB * 2 + V], &r, &g, &b);
+          get_uv_values (&itu601_narrow, uv_data[x / X_SUB * 2 + U], uv_data[x / X_SUB * 2 + V], &r, &g, &b);
 
           for (ys = 0; ys < Y_SUB && y + ys < height; ys++)
             for (xs = 0; xs < X_SUB && x + xs < width; xs++)
@@ -309,7 +309,7 @@ download_yuv_3 (guchar          *dst_data,
           int r, g, b;
           gsize xs, ys;
 
-          get_uv_values (&itu601_wide, u_data[x / X_SUB], v_data[x / X_SUB], &r, &g, &b);
+          get_uv_values (&itu601_narrow, u_data[x / X_SUB], v_data[x / X_SUB], &r, &g, &b);
 
           for (ys = 0; ys < Y_SUB && y + ys < height; ys++)
             for (xs = 0; xs < X_SUB && x + xs < width; xs++)
@@ -365,7 +365,7 @@ download_yuyv (guchar          *dst_data,
         {
           int r, g, b;
 
-          get_uv_values (&itu601_wide, src_data[2 * x + U], src_data[2 * x + V], &r, &g, &b);
+          get_uv_values (&itu601_narrow, src_data[2 * x + U], src_data[2 * x + V], &r, &g, &b);
           set_rgb_values (&dst_data[3 * x], src_data[2 * x + Y1], r, g, b);
           if (x + 1 < width)
             set_rgb_values (&dst_data[3 * (x + 1)], src_data[2 * x + Y2], r, g, b);
@@ -2329,18 +2329,42 @@ gdk_dmabuf_sanitize (GdkDmabuf        *dest,
  * @dmabuf: a sanitized GdkDmabuf
  *
  * A dmabuf is considered disjoint if it uses more than
- * 1 file descriptor.
+ * 1 inode.
+ * Multiple file descriptors may exist when the creator
+ * of the dmabuf just dup()ed once for every plane...
  *
  * Returns: %TRUE if the dmabuf is disjoint
  **/
 gboolean
 gdk_dmabuf_is_disjoint (const GdkDmabuf *dmabuf)
 {
+  struct stat first_stat;
   unsigned i;
 
+  /* First, do a fast check */
+
   for (i = 1; i < dmabuf->n_planes; i++)
     {
       if (dmabuf->planes[0].fd != dmabuf->planes[i].fd)
+        break;
+    }
+
+  if (i == dmabuf->n_planes)
+    return FALSE;
+
+  /* We have different fds, do the fancy check instead */
+
+  if (fstat (dmabuf->planes[0].fd, &first_stat) != 0)
+    return TRUE;
+
+  for (i = 1; i < dmabuf->n_planes; i++)
+    {
+      struct stat plane_stat;
+
+      if (fstat (dmabuf->planes[0].fd, &plane_stat) != 0)
+        return TRUE;
+
+      if (first_stat.st_ino != plane_stat.st_ino)
         return TRUE;
     }
 
