@@ -327,6 +327,7 @@ ADD_ALPHA_FUNC(r8g8b8_to_a8b8g8r8, 0, 1, 2, 3, 2, 1, 0)
 
 struct _GdkMemoryFormatDescription
 {
+  const char *name;
   GdkMemoryAlpha alpha;
   GdkMemoryFormat premultiplied;
   GdkMemoryFormat straight;
@@ -335,7 +336,8 @@ struct _GdkMemoryFormatDescription
   GdkMemoryDepth depth;
   const GdkMemoryFormat *fallbacks;
   struct {
-    GLint internal_format;
+    GLint internal_gl_format;
+    GLint internal_gles_format;
     GLenum format;
     GLenum type;
     GLint swizzle[4];
@@ -365,6 +367,7 @@ struct _GdkMemoryFormatDescription
 
 static const GdkMemoryFormatDescription memory_formats[] = {
   [GDK_MEMORY_B8G8R8A8_PREMULTIPLIED] = {
+    .name = "*BGRA8",
     .alpha = GDK_MEMORY_ALPHA_PREMULTIPLIED,
     .premultiplied = GDK_MEMORY_B8G8R8A8_PREMULTIPLIED,
     .straight = GDK_MEMORY_B8G8R8A8,
@@ -375,7 +378,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA8,
+        .internal_gl_format = GL_RGBA8,
+        .internal_gles_format = GL_BGRA,
         .format = GL_BGRA,
         .type = GL_UNSIGNED_BYTE,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -392,6 +396,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = b8g8r8a8_premultiplied_from_float,
   },
   [GDK_MEMORY_A8R8G8B8_PREMULTIPLIED] = {
+    .name = "*ARGB8",
     .alpha = GDK_MEMORY_ALPHA_PREMULTIPLIED,
     .premultiplied = GDK_MEMORY_A8R8G8B8_PREMULTIPLIED,
     .straight = GDK_MEMORY_A8R8G8B8,
@@ -402,7 +407,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA8,
+        .internal_gl_format = GL_RGBA8,
+        .internal_gles_format = GL_RGBA8,
         .format = GL_BGRA,
         .type = GDK_GL_UNSIGNED_BYTE_FLIPPED,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -419,6 +425,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = a8r8g8b8_premultiplied_from_float,
   },
   [GDK_MEMORY_R8G8B8A8_PREMULTIPLIED] = {
+    .name = "*RGBA8",
     .alpha = GDK_MEMORY_ALPHA_PREMULTIPLIED,
     .premultiplied = GDK_MEMORY_R8G8B8A8_PREMULTIPLIED,
     .straight = GDK_MEMORY_R8G8B8A8,
@@ -429,7 +436,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA8,
+        .internal_gl_format = GL_RGBA8,
+        .internal_gles_format = GL_RGBA8,
         .format = GL_RGBA,
         .type = GL_UNSIGNED_BYTE,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -445,6 +453,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = r8g8b8a8_premultiplied_from_float,
   },
   [GDK_MEMORY_A8B8G8R8_PREMULTIPLIED] = {
+    .name = "*ABGR8",
     .alpha = GDK_MEMORY_ALPHA_PREMULTIPLIED,
     .premultiplied = GDK_MEMORY_A8B8G8R8_PREMULTIPLIED,
     .straight = GDK_MEMORY_A8B8G8R8,
@@ -455,7 +464,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA8,
+        .internal_gl_format = GL_RGBA8,
+        .internal_gles_format = GL_RGBA8,
         .format = GL_RGBA,
         .type = GDK_GL_UNSIGNED_BYTE_FLIPPED,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -472,6 +482,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = a8b8g8r8_premultiplied_from_float,
   },
   [GDK_MEMORY_B8G8R8A8] = {
+    .name = "BGRA8",
     .alpha = GDK_MEMORY_ALPHA_STRAIGHT,
     .premultiplied = GDK_MEMORY_B8G8R8A8_PREMULTIPLIED,
     .straight = GDK_MEMORY_B8G8R8A8,
@@ -482,7 +493,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA8,
+        .internal_gl_format = GL_RGBA8,
+        .internal_gles_format = GL_BGRA,
         .format = GL_BGRA,
         .type = GL_UNSIGNED_BYTE,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -499,6 +511,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = b8g8r8a8_from_float,
   },
   [GDK_MEMORY_A8R8G8B8] = {
+    .name = "ARGB8",
     .alpha = GDK_MEMORY_ALPHA_STRAIGHT,
     .premultiplied = GDK_MEMORY_A8R8G8B8_PREMULTIPLIED,
     .straight = GDK_MEMORY_A8R8G8B8,
@@ -509,7 +522,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA8,
+        .internal_gl_format = GL_RGBA8,
+        .internal_gles_format = GL_RGBA8,
         .format = GL_BGRA,
         .type = GDK_GL_UNSIGNED_BYTE_FLIPPED,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -526,6 +540,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = a8r8g8b8_from_float,
   },
   [GDK_MEMORY_R8G8B8A8] = {
+    .name = "RGBA8",
     .alpha = GDK_MEMORY_ALPHA_STRAIGHT,
     .premultiplied = GDK_MEMORY_R8G8B8A8_PREMULTIPLIED,
     .straight = GDK_MEMORY_R8G8B8A8,
@@ -536,7 +551,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA8,
+        .internal_gl_format = GL_RGBA8,
+        .internal_gles_format = GL_RGBA8,
         .format = GL_RGBA,
         .type = GL_UNSIGNED_BYTE,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -552,6 +568,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = r8g8b8a8_from_float,
   },
   [GDK_MEMORY_A8B8G8R8] = {
+    .name = "ABGR8",
     .alpha = GDK_MEMORY_ALPHA_STRAIGHT,
     .premultiplied = GDK_MEMORY_A8B8G8R8_PREMULTIPLIED,
     .straight = GDK_MEMORY_A8B8G8R8,
@@ -562,7 +579,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA8,
+        .internal_gl_format = GL_RGBA8,
+        .internal_gles_format = GL_RGBA8,
         .format = GL_RGBA,
         .type = GDK_GL_UNSIGNED_BYTE_FLIPPED,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -579,6 +597,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = a8b8g8r8_from_float,
   },
   [GDK_MEMORY_B8G8R8X8] = {
+    .name = "BGRX8",
     .alpha = GDK_MEMORY_ALPHA_OPAQUE,
     .premultiplied = GDK_MEMORY_B8G8R8X8,
     .straight = GDK_MEMORY_B8G8R8X8,
@@ -590,7 +609,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA8,
+        .internal_gl_format = GL_RGBA8,
+        .internal_gles_format = GL_BGRA,
         .format = GL_BGRA,
         .type = GL_UNSIGNED_BYTE,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ONE },
@@ -607,6 +627,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = b8g8r8x8_from_float,
   },
   [GDK_MEMORY_X8R8G8B8] = {
+    .name = "XRGB8",
     .alpha = GDK_MEMORY_ALPHA_OPAQUE,
     .premultiplied = GDK_MEMORY_X8R8G8B8,
     .straight = GDK_MEMORY_X8R8G8B8,
@@ -618,7 +639,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA8,
+        .internal_gl_format = GL_RGBA8,
+        .internal_gles_format = GL_RGBA8,
         .format = GL_BGRA,
         .type = GDK_GL_UNSIGNED_BYTE_FLIPPED,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ONE },
@@ -635,6 +657,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = x8r8g8b8_from_float,
   },
   [GDK_MEMORY_R8G8B8X8] = {
+    .name = "RGBX8",
     .alpha = GDK_MEMORY_ALPHA_OPAQUE,
     .premultiplied = GDK_MEMORY_R8G8B8X8,
     .straight = GDK_MEMORY_R8G8B8X8,
@@ -646,7 +669,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA8,
+        .internal_gl_format = GL_RGBA8,
+        .internal_gles_format = GL_RGBA8,
         .format = GL_RGBA,
         .type = GL_UNSIGNED_BYTE,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ONE },
@@ -662,6 +686,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = r8g8b8x8_from_float,
   },
   [GDK_MEMORY_X8B8G8R8] = {
+    .name = "XBGR8",
     .alpha = GDK_MEMORY_ALPHA_OPAQUE,
     .premultiplied = GDK_MEMORY_X8B8G8R8,
     .straight = GDK_MEMORY_X8B8G8R8,
@@ -673,7 +698,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA8,
+        .internal_gl_format = GL_RGBA8,
+        .internal_gles_format = GL_RGBA8,
         .format = GL_RGBA,
         .type = GDK_GL_UNSIGNED_BYTE_FLIPPED,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ONE },
@@ -690,6 +716,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = x8b8g8r8_from_float,
   },
   [GDK_MEMORY_R8G8B8] = {
+    .name = "RGB8",
     .alpha = GDK_MEMORY_ALPHA_OPAQUE,
     .premultiplied = GDK_MEMORY_R8G8B8,
     .straight = GDK_MEMORY_R8G8B8,
@@ -701,7 +728,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGB8,
+        .internal_gl_format = GL_RGB8,
+        .internal_gles_format = GL_RGB8,
         .format = GL_RGB,
         .type = GL_UNSIGNED_BYTE,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -717,6 +745,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = r8g8b8_from_float,
   },
   [GDK_MEMORY_B8G8R8] = {
+    .name = "BGR8",
     .alpha = GDK_MEMORY_ALPHA_OPAQUE,
     .premultiplied = GDK_MEMORY_B8G8R8,
     .straight = GDK_MEMORY_B8G8R8,
@@ -728,7 +757,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGB8,
+        .internal_gl_format = GL_RGB8,
+        .internal_gles_format = GL_RGB8,
         .format = GL_BGR,
         .type = GL_UNSIGNED_BYTE,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -745,6 +775,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = b8g8r8_from_float,
   },
   [GDK_MEMORY_R16G16B16] = {
+    .name = "RGB16",
     .alpha = GDK_MEMORY_ALPHA_OPAQUE,
     .premultiplied = GDK_MEMORY_R16G16B16,
     .straight = GDK_MEMORY_R16G16B16,
@@ -759,7 +790,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGB16,
+        .internal_gl_format = GL_RGB16,
+        .internal_gles_format = GL_RGB16,
         .format = GL_RGB,
         .type = GL_UNSIGNED_SHORT,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -775,6 +807,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = r16g16b16_from_float,
   },
   [GDK_MEMORY_R16G16B16A16_PREMULTIPLIED] = {
+    .name = "*RGBA16",
     .alpha = GDK_MEMORY_ALPHA_PREMULTIPLIED,
     .premultiplied = GDK_MEMORY_R16G16B16A16_PREMULTIPLIED,
     .straight = GDK_MEMORY_R16G16B16A16,
@@ -788,7 +821,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA16,
+        .internal_gl_format = GL_RGBA16,
+        .internal_gles_format = GL_RGBA16,
         .format = GL_RGBA,
         .type = GL_UNSIGNED_SHORT,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -804,6 +838,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = r16g16b16a16_from_float,
   },
   [GDK_MEMORY_R16G16B16A16] = {
+    .name = "RGBA16",
     .alpha = GDK_MEMORY_ALPHA_STRAIGHT,
     .premultiplied = GDK_MEMORY_R16G16B16A16_PREMULTIPLIED,
     .straight = GDK_MEMORY_R16G16B16A16,
@@ -817,7 +852,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA16,
+        .internal_gl_format = GL_RGBA16,
+        .internal_gles_format = GL_RGBA16,
         .format = GL_RGBA,
         .type = GL_UNSIGNED_SHORT,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -833,6 +869,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = r16g16b16a16_from_float,
   },
   [GDK_MEMORY_R16G16B16_FLOAT] = {
+    .name = "RGBA16f",
     .alpha = GDK_MEMORY_ALPHA_OPAQUE,
     .premultiplied = GDK_MEMORY_R16G16B16_FLOAT,
     .straight = GDK_MEMORY_R16G16B16_FLOAT,
@@ -846,7 +883,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGB16F,
+        .internal_gl_format = GL_RGB16F,
+        .internal_gles_format = GL_RGB16F,
         .format = GL_RGB,
         .type = GL_HALF_FLOAT,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -862,6 +900,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = r16g16b16_float_from_float,
   },
   [GDK_MEMORY_R16G16B16A16_FLOAT_PREMULTIPLIED] = {
+    .name = "*RGBA16f",
     .alpha = GDK_MEMORY_ALPHA_PREMULTIPLIED,
     .premultiplied = GDK_MEMORY_R16G16B16A16_FLOAT_PREMULTIPLIED,
     .straight = GDK_MEMORY_R16G16B16A16_FLOAT,
@@ -874,7 +913,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA16F,
+        .internal_gl_format = GL_RGBA16F,
+        .internal_gles_format = GL_RGBA16F,
         .format = GL_RGBA,
         .type = GL_HALF_FLOAT,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -890,6 +930,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = r16g16b16a16_float_from_float,
   },
   [GDK_MEMORY_R16G16B16A16_FLOAT] = {
+    .name = "RGBA16f",
     .alpha = GDK_MEMORY_ALPHA_STRAIGHT,
     .premultiplied = GDK_MEMORY_R16G16B16A16_FLOAT_PREMULTIPLIED,
     .straight = GDK_MEMORY_R16G16B16A16_FLOAT,
@@ -902,7 +943,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA16F,
+        .internal_gl_format = GL_RGBA16F,
+        .internal_gles_format = GL_RGBA16F,
         .format = GL_RGBA,
         .type = GL_HALF_FLOAT,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -918,6 +960,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = r16g16b16a16_float_from_float,
   },
   [GDK_MEMORY_R32G32B32_FLOAT] = {
+    .name = "RGB32f",
     .alpha = GDK_MEMORY_ALPHA_OPAQUE,
     .premultiplied = GDK_MEMORY_R32G32B32_FLOAT,
     .straight = GDK_MEMORY_R32G32B32_FLOAT,
@@ -931,7 +974,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGB32F,
+        .internal_gl_format = GL_RGB32F,
+        .internal_gles_format = GL_RGB32F,
         .format = GL_RGB,
         .type = GL_FLOAT,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -947,6 +991,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = r32g32b32_float_from_float,
   },
   [GDK_MEMORY_R32G32B32A32_FLOAT_PREMULTIPLIED] = {
+    .name = "*RGBA32f",
     .alpha = GDK_MEMORY_ALPHA_PREMULTIPLIED,
     .premultiplied = GDK_MEMORY_R32G32B32A32_FLOAT_PREMULTIPLIED,
     .straight = GDK_MEMORY_R32G32B32A32_FLOAT,
@@ -959,7 +1004,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA32F,
+        .internal_gl_format = GL_RGBA32F,
+        .internal_gles_format = GL_RGBA32F,
         .format = GL_RGBA,
         .type = GL_FLOAT,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -975,6 +1021,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = r32g32b32a32_float_from_float,
   },
   [GDK_MEMORY_R32G32B32A32_FLOAT] = {
+    .name = "RGBA32f",
     .alpha = GDK_MEMORY_ALPHA_STRAIGHT,
     .premultiplied = GDK_MEMORY_R32G32B32A32_FLOAT_PREMULTIPLIED,
     .straight = GDK_MEMORY_R32G32B32A32_FLOAT,
@@ -987,7 +1034,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RGBA32F,
+        .internal_gl_format = GL_RGBA32F,
+        .internal_gles_format = GL_RGBA32F,
         .format = GL_RGBA,
         .type = GL_FLOAT,
         .swizzle = { GL_RED, GL_GREEN, GL_BLUE, GL_ALPHA },
@@ -1003,6 +1051,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = r32g32b32a32_float_from_float,
   },
   [GDK_MEMORY_G8A8_PREMULTIPLIED] = {
+    .name = "*GA8",
     .alpha = GDK_MEMORY_ALPHA_PREMULTIPLIED,
     .premultiplied = GDK_MEMORY_G8A8_PREMULTIPLIED,
     .straight = GDK_MEMORY_G8A8,
@@ -1014,7 +1063,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RG8,
+        .internal_gl_format = GL_RG8,
+        .internal_gles_format = GL_RG8,
         .format = GL_RG,
         .type = GL_UNSIGNED_BYTE,
         .swizzle = { GL_RED, GL_RED, GL_RED, GL_GREEN },
@@ -1030,6 +1080,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = g8a8_premultiplied_from_float,
   },
   [GDK_MEMORY_G8A8] = {
+    .name = "GA8",
     .alpha = GDK_MEMORY_ALPHA_STRAIGHT,
     .premultiplied = GDK_MEMORY_G8A8_PREMULTIPLIED,
     .straight = GDK_MEMORY_G8A8,
@@ -1041,7 +1092,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RG8,
+        .internal_gl_format = GL_RG8,
+        .internal_gles_format = GL_RG8,
         .format = GL_RG,
         .type = GL_UNSIGNED_BYTE,
         .swizzle = { GL_RED, GL_RED, GL_RED, GL_GREEN },
@@ -1057,6 +1109,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = g8a8_from_float,
   },
   [GDK_MEMORY_G8] = {
+    .name = "G8",
     .alpha = GDK_MEMORY_ALPHA_OPAQUE,
     .premultiplied = GDK_MEMORY_G8,
     .straight = GDK_MEMORY_G8,
@@ -1068,7 +1121,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_R8,
+        .internal_gl_format = GL_R8,
+        .internal_gles_format = GL_R8,
         .format = GL_RED,
         .type = GL_UNSIGNED_BYTE,
         .swizzle = { GL_RED, GL_RED, GL_RED, GL_ONE },
@@ -1084,6 +1138,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = g8_from_float,
   },
   [GDK_MEMORY_G16A16_PREMULTIPLIED] = {
+    .name = "*GA16",
     .alpha = GDK_MEMORY_ALPHA_PREMULTIPLIED,
     .premultiplied = GDK_MEMORY_G16A16_PREMULTIPLIED,
     .straight = GDK_MEMORY_G16A16,
@@ -1098,7 +1153,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RG16,
+        .internal_gl_format = GL_RG16,
+        .internal_gles_format = GL_RG16,
         .format = GL_RG,
         .type = GL_UNSIGNED_SHORT,
         .swizzle = { GL_RED, GL_RED, GL_RED, GL_GREEN },
@@ -1114,6 +1170,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = g16a16_premultiplied_from_float,
   },
   [GDK_MEMORY_G16A16] = {
+    .name = "GA16",
     .alpha = GDK_MEMORY_ALPHA_STRAIGHT,
     .premultiplied = GDK_MEMORY_G16A16_PREMULTIPLIED,
     .straight = GDK_MEMORY_G16A16,
@@ -1128,7 +1185,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_RG16,
+        .internal_gl_format = GL_RG16,
+        .internal_gles_format = GL_RG16,
         .format = GL_RG,
         .type = GL_UNSIGNED_SHORT,
         .swizzle = { GL_RED, GL_RED, GL_RED, GL_GREEN },
@@ -1144,6 +1202,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = g16a16_from_float,
   },
   [GDK_MEMORY_G16] = {
+    .name = "G16",
     .alpha = GDK_MEMORY_ALPHA_OPAQUE,
     .premultiplied = GDK_MEMORY_G16,
     .straight = GDK_MEMORY_G16,
@@ -1158,7 +1217,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_R16,
+        .internal_gl_format = GL_R16,
+        .internal_gles_format = GL_R16,
         .format = GL_RED,
         .type = GL_UNSIGNED_SHORT,
         .swizzle = { GL_RED, GL_RED, GL_RED, GL_ONE },
@@ -1174,6 +1234,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = g16_from_float,
   },
   [GDK_MEMORY_A8] = {
+    .name = "A8",
     .alpha = GDK_MEMORY_ALPHA_PREMULTIPLIED,
     .premultiplied = GDK_MEMORY_A8,
     .straight = GDK_MEMORY_A8,
@@ -1185,7 +1246,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_R8,
+        .internal_gl_format = GL_R8,
+        .internal_gles_format = GL_R8,
         .format = GL_RED,
         .type = GL_UNSIGNED_BYTE,
         .swizzle = { GL_RED, GL_RED, GL_RED, GL_RED },
@@ -1201,6 +1263,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = a8_from_float,
   },
   [GDK_MEMORY_A16] = {
+    .name = "A16",
     .alpha = GDK_MEMORY_ALPHA_PREMULTIPLIED,
     .premultiplied = GDK_MEMORY_A16,
     .straight = GDK_MEMORY_A16,
@@ -1215,7 +1278,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_R16,
+        .internal_gl_format = GL_R16,
+        .internal_gles_format = GL_R16,
         .format = GL_RED,
         .type = GL_UNSIGNED_SHORT,
         .swizzle = { GL_RED, GL_RED, GL_RED, GL_RED },
@@ -1231,6 +1295,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = a16_from_float,
   },
   [GDK_MEMORY_A16_FLOAT] = {
+    .name = "A16f",
     .alpha = GDK_MEMORY_ALPHA_PREMULTIPLIED,
     .premultiplied = GDK_MEMORY_A16_FLOAT,
     .straight = GDK_MEMORY_A16_FLOAT,
@@ -1244,7 +1309,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_R16F,
+        .internal_gl_format = GL_R16F,
+        .internal_gles_format = GL_R16F,
         .format = GL_RED,
         .type = GL_HALF_FLOAT,
         .swizzle = { GL_RED, GL_RED, GL_RED, GL_RED },
@@ -1260,6 +1326,7 @@ static const GdkMemoryFormatDescription memory_formats[] = {
     .from_float = a16_float_from_float,
   },
   [GDK_MEMORY_A32_FLOAT] = {
+    .name = "A32f",
     .alpha = GDK_MEMORY_ALPHA_PREMULTIPLIED,
     .premultiplied = GDK_MEMORY_A32_FLOAT,
     .straight = GDK_MEMORY_A32_FLOAT,
@@ -1273,7 +1340,8 @@ static const GdkMemoryFormatDescription memory_formats[] = {
         -1,
     },
     .gl = {
-        .internal_format = GL_R32F,
+        .internal_gl_format = GL_R32F,
+        .internal_gles_format = GL_R32F,
         .format = GL_RED,
         .type = GL_FLOAT,
         .swizzle = { GL_RED, GL_RED, GL_RED, GL_RED },
@@ -1387,7 +1455,7 @@ gdk_memory_format_get_depth (GdkMemoryFormat format)
  * @depth1: the first depth
  * @depth2: the second depth
  *
- * Returns a depth that can accomodate both given depths
+ * Returns a depth that can accommodate both given depths
  * without any loss of precision.
  *
  * Returns: The merged depth
@@ -1473,12 +1541,16 @@ gdk_memory_depth_get_alpha_format (GdkMemoryDepth depth)
 
 void
 gdk_memory_format_gl_format (GdkMemoryFormat  format,
+                             gboolean         gles,
                              GLint           *out_internal_format,
                              GLenum          *out_format,
                              GLenum          *out_type,
                              GLint            out_swizzle[4])
 {
-  *out_internal_format = memory_formats[format].gl.internal_format;
+  if (gles)
+    *out_internal_format = memory_formats[format].gl.internal_gles_format;
+  else
+    *out_internal_format = memory_formats[format].gl.internal_gl_format;
   *out_format = memory_formats[format].gl.format;
   *out_type = memory_formats[format].gl.type;
   memcpy (out_swizzle, memory_formats[format].gl.swizzle, sizeof(GLint) * 4);
@@ -1487,6 +1559,7 @@ gdk_memory_format_gl_format (GdkMemoryFormat  format,
 /*
  * gdk_memory_format_gl_rgba_format:
  * @format: The format to query
+ * @gles: TRUE for GLES, FALSE for GL
  * @out_actual_format: The actual RGBA format
  * @out_internal_format: the GL internal format
  * @out_format: the GL format
@@ -1504,6 +1577,7 @@ gdk_memory_format_gl_format (GdkMemoryFormat  format,
  **/
 gboolean
 gdk_memory_format_gl_rgba_format (GdkMemoryFormat  format,
+                                  gboolean         gles,
                                   GdkMemoryFormat *out_actual_format,
                                   GLint           *out_internal_format,
                                   GLenum          *out_format,
@@ -1516,7 +1590,10 @@ gdk_memory_format_gl_rgba_format (GdkMemoryFormat  format,
     return FALSE;
 
   *out_actual_format = actual;
-  *out_internal_format = memory_formats[actual].gl.internal_format;
+  if (gles)
+    *out_internal_format = memory_formats[actual].gl.internal_gles_format;
+  else
+    *out_internal_format = memory_formats[actual].gl.internal_gl_format;
   *out_format = memory_formats[actual].gl.format;
   *out_type = memory_formats[actual].gl.type;
   memcpy (out_swizzle, memory_formats[format].gl.rgba_swizzle, sizeof(GLint) * 4);
@@ -1618,6 +1695,12 @@ gdk_memory_format_get_dmabuf_fourcc (GdkMemoryFormat format)
 #endif
 }
 
+const char *
+gdk_memory_format_get_name (GdkMemoryFormat format)
+{
+  return memory_formats[format].name;
+}
+
 static void
 premultiply (float *rgba,
              gsize  n)
