@@ -131,7 +131,7 @@ gdk_win32_gl_context_wgl_begin_frame (GdkDrawContext *draw_context,
   GDK_DRAW_CONTEXT_CLASS (gdk_win32_gl_context_wgl_parent_class)->begin_frame (draw_context, depth, update_area);
 }
 
-#define PIXEL_ATTRIBUTES 17
+#define PIXEL_ATTRIBUTES 21
 
 static int
 get_wgl_pfd (HDC                    hdc,
@@ -142,8 +142,7 @@ get_wgl_pfd (HDC                    hdc,
 
   pfd->nSize = sizeof (PIXELFORMATDESCRIPTOR);
 
-  if (display_win32 != NULL &&
-      display_win32->hasWglARBPixelFormat)
+  if (display_win32->hasWglARBPixelFormat)
     {
       UINT num_formats;
       int colorbits = GetDeviceCaps (hdc, BITSPIXEL);
@@ -176,10 +175,22 @@ get_wgl_pfd (HDC                    hdc,
       pixelAttribs[i++] = WGL_ALPHA_BITS_ARB;
       pixelAttribs[i++] = 8;
 
+      pixelAttribs[i++] = WGL_STENCIL_BITS_ARB;
+      pixelAttribs[i++] = 0;
+
+      pixelAttribs[i++] = WGL_ACCUM_BITS_ARB;
+      pixelAttribs[i++] = 0;
+
+      if (!display_win32->force_enable_depth_bits)
+        {
+          pixelAttribs[i++] = WGL_DEPTH_BITS_ARB;
+          pixelAttribs[i++] = 0;
+        }
+
       /* end of "Update PIXEL_ATTRIBUTES above if any groups are added here!" */
 
       pixelAttribs[i++] = 0; /* end of pixelAttribs */
-      g_assert (i <= PIXEL_ATTRIBUTES);
+      g_assert (i == PIXEL_ATTRIBUTES);
 
       if (!wglMakeCurrent (display_win32->dummy_context_wgl.hdc,
                            display_win32->dummy_context_wgl.hglrc))
@@ -205,9 +216,21 @@ get_wgl_pfd (HDC                    hdc,
       pfd->iPixelType = PFD_TYPE_RGBA;
       pfd->cColorBits = GetDeviceCaps (hdc, BITSPIXEL);
       pfd->cAlphaBits = 8;
-      pfd->dwLayerMask = PFD_MAIN_PLANE;
+      pfd->iLayerType = PFD_MAIN_PLANE;
+      pfd->cAccumBits = 0;
+      pfd->cStencilBits = 0;
+
+      if (!display_win32->force_enable_depth_bits)
+        pfd->cDepthBits = 0;
 
       best_pf = ChoosePixelFormat (hdc, pfd);
+
+      /* try again if driver enforces depth buffers */
+      if (best_pf == 0 && !display_win32->force_enable_depth_bits)
+        {
+          display_win32->force_enable_depth_bits = TRUE;
+          get_wgl_pfd (hdc, pfd, display_win32);
+        }
     }
 
   return best_pf;
@@ -225,7 +248,7 @@ gdk_init_dummy_wgl_context (GdkWin32Display *display_win32)
 
   memset (&pfd, 0, sizeof (PIXELFORMATDESCRIPTOR));
 
-  best_idx = get_wgl_pfd (display_win32->dummy_context_wgl.hdc, &pfd, NULL);
+  best_idx = get_wgl_pfd (display_win32->dummy_context_wgl.hdc, &pfd, display_win32);
 
   if (best_idx != 0)
     set_pixel_format_result = SetPixelFormat (display_win32->dummy_context_wgl.hdc,
@@ -258,9 +281,9 @@ create_dummy_gl_window (void)
 {
   WNDCLASS wclass = { 0, };
   ATOM klass;
-  HWND hwnd;
+  HWND hwnd = NULL;
 
-  wclass.lpszClassName = "GdkGLDummyWindow";
+  wclass.lpszClassName = L"GdkGLDummyWindow";
   wclass.lpfnWndProc = DefWindowProc;
   wclass.hInstance = this_module ();
   wclass.style = CS_OWNDC;
@@ -604,7 +627,7 @@ set_wgl_pixformat_for_hdc (GdkWin32Display *display_win32,
 {
   gboolean skip_acquire = FALSE;
   gboolean set_pixel_format_result = FALSE;
-  PIXELFORMATDESCRIPTOR pfd;
+  PIXELFORMATDESCRIPTOR pfd = {0};
 
   /* one is only allowed to call SetPixelFormat(), and so ChoosePixelFormat()
    * one single time per window HDC
