@@ -15,8 +15,7 @@
  * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GDK_WIN32_KEYS_H__
-#define __GDK_WIN32_KEYS_H__
+#pragma once
 
 #if !defined (__GDKWIN32_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gdk/gdkwin32.h> can be included directly."
@@ -32,7 +31,7 @@ G_BEGIN_DECLS
  * @GDK_WIN32_KEYMAP_MATCH_NONE: no matches found. Output is not valid.
  * @GDK_WIN32_KEYMAP_MATCH_INCOMPLETE: the sequence matches so far, but is incomplete. Output is not valid.
  * @GDK_WIN32_KEYMAP_MATCH_PARTIAL: the sequence matches up to the last key,
- *     which does not match. Output is valid.
+ *   which does not match. Output is valid.
  * @GDK_WIN32_KEYMAP_MATCH_EXACT: the sequence matches exactly. Output is valid.
  *
  * An enumeration describing the result of a deadkey combination matching.
@@ -61,12 +60,5 @@ typedef struct _GdkWin32KeymapClass GdkWin32KeymapClass;
 
 GType gdk_win32_keymap_get_type (void);
 
-GdkWin32KeymapMatch gdk_win32_keymap_check_compose (GdkWin32Keymap *keymap,
-                                                    guint16        *compose_buffer,
-                                                    gsize           compose_buffer_len,
-                                                    guint16        *output,
-                                                    gsize          *output_len);
-
 G_END_DECLS
 
-#endif /* __GDK_WIN32_KEYMAP_H__ */
