@@ -10,6 +10,13 @@
 #include "gskrendernodeprivate.h"
 #include "gdk/gdktextureprivate.h"
 
+/**
+ * GskBroadwayRenderer:
+ *
+ * A Broadway based renderer.
+ *
+ * See [class@Gsk.Renderer].
+ */
 struct _GskBroadwayRenderer
 {
   GskRenderer parent_instance;
@@ -35,6 +42,7 @@ G_DEFINE_TYPE (GskBroadwayRenderer, gsk_broadway_renderer, GSK_TYPE_RENDERER)
 
 static gboolean
 gsk_broadway_renderer_realize (GskRenderer  *renderer,
+                               GdkDisplay   *display,
                                GdkSurface   *surface,
                                GError      **error)
 {
@@ -273,6 +281,7 @@ collect_reused_child_nodes (GskRenderer *renderer,
     case GSK_MASK_NODE:
     case GSK_FILL_NODE:
     case GSK_STROKE_NODE:
+    case GSK_SUBSURFACE_NODE:
 
     default:
 
@@ -803,6 +812,11 @@ gsk_broadway_renderer_add_node (GskRenderer *renderer,
         }
       return;
 
+    case GSK_SUBSURFACE_NODE:
+      gsk_broadway_renderer_add_node (renderer,
+                                      gsk_subsurface_node_get_child (node), offset_x, offset_y, clip_bounds);
+     return;
+
       /* Generic nodes */
 
     case GSK_CONTAINER_NODE:
