@@ -21,22 +21,16 @@ color_equal (const float *color1,
              const float *color2)
 {
   return gdk_rgba_equal (&(GdkRGBA) { color1[0], color1[1], color1[2], color1[3] },
-                         &(GdkRGBA) { color1[0], color1[1], color1[2], color1[3] });
+                         &(GdkRGBA) { color2[0], color2[1], color2[2], color2[3] });
 }
 
 static void
-gsk_gpu_border_op_print (GskGpuOp    *op,
-                         GskGpuFrame *frame,
-                         GString     *string,
-                         guint        indent)
+gsk_gpu_border_op_print_instance (GskGpuShaderOp *shader,
+                                  gpointer        instance_,
+                                  GString        *string)
 {
-  GskGpuShaderOp *shader = (GskGpuShaderOp *) op;
-  GskGpuBorderInstance *instance;
+  GskGpuBorderInstance *instance = (GskGpuBorderInstance *) instance_;
 
-  instance = (GskGpuBorderInstance *) gsk_gpu_frame_get_vertex_data (frame, shader->vertex_offset);
-
-  gsk_gpu_print_op (string, indent, "border");
-  gsk_gpu_print_shader_info (string, shader->clip);
   gsk_gpu_print_rounded_rect (string, instance->outline);
 
   gsk_gpu_print_rgba (string, (const float *) &instance->border_colors[0]);
@@ -58,8 +52,6 @@ gsk_gpu_border_op_print (GskGpuOp    *op,
                               instance->border_widths[2],
                               instance->border_widths[3]);
     }
-
-  gsk_gpu_print_newline (string);
 }
 
 #ifdef GDK_RENDERING_VULKAN
@@ -85,7 +77,7 @@ static const GskGpuShaderOpClass GSK_GPU_BORDER_OP_CLASS = {
     GSK_GPU_OP_SIZE (GskGpuBorderOp),
     GSK_GPU_STAGE_SHADER,
     gsk_gpu_shader_op_finish,
-    gsk_gpu_border_op_print,
+    gsk_gpu_shader_op_print,
 #ifdef GDK_RENDERING_VULKAN
     gsk_gpu_border_op_vk_command,
 #endif
@@ -96,6 +88,7 @@ static const GskGpuShaderOpClass GSK_GPU_BORDER_OP_CLASS = {
 #ifdef GDK_RENDERING_VULKAN
   &gsk_gpu_border_info,
 #endif
+  gsk_gpu_border_op_print_instance,
   gsk_gpu_border_setup_attrib_locations,
   gsk_gpu_border_setup_vao
 };
