@@ -162,7 +162,6 @@ uniform_type_from_glsl (const char *str)
   return  GSK_GL_UNIFORM_TYPE_NONE;
 }
 
-#ifdef G_ENABLE_DEBUG
 static const char *
 uniform_type_name (GskGLUniformType type)
 {
@@ -195,7 +194,6 @@ uniform_type_name (GskGLUniformType type)
       return NULL;
     }
 }
-#endif
 
 static int
 uniform_type_size (GskGLUniformType type)
@@ -399,7 +397,6 @@ gsk_gl_shader_constructed (GObject *object)
 
   shader->n_textures = max_texture_seen;
 
-#ifdef G_ENABLE_DEBUG
   if (GSK_DEBUG_CHECK(SHADERS))
     {
       GString *s;
@@ -417,7 +414,6 @@ gsk_gl_shader_constructed (GObject *object)
                  s->str);
       g_string_free (s, TRUE);
     }
-#endif
 }
 
 #define SPACE_RE "[ \\t]+" // Don't use \s, we don't want to match newlines
@@ -443,7 +439,7 @@ gsk_gl_shader_class_init (GskGLShaderClass *klass)
   object_class->constructed = gsk_gl_shader_constructed;
 
   /**
-   * GskGLShader:sourcecode: (attributes org.gtk.Property.get=gsk_gl_shader_get_source)
+   * GskGLShader:source: (attributes org.gtk.Property.get=gsk_gl_shader_get_source)
    *
    * The source code for the shader, as a `GBytes`.
    */
