@@ -382,15 +382,35 @@ gsk_matrix_transform_print (GskTransform *transform,
   guint i;
   float f[16];
 
-  g_string_append (string, "matrix3d(");
-  graphene_matrix_to_float (&self->matrix, f);
-  for (i = 0; i < 16; i++)
+  if (transform->category >= GSK_TRANSFORM_CATEGORY_2D)
     {
-      if (i > 0)
-        g_string_append (string, ", ");
-      string_append_double (string, f[i]);
+      g_string_append (string, "matrix(");
+      graphene_matrix_to_float (&self->matrix, f);
+      string_append_double (string, f[0]);
+      g_string_append (string, ", ");
+      string_append_double (string, f[1]);
+      g_string_append (string, ", ");
+      string_append_double (string, f[4]);
+      g_string_append (string, ", ");
+      string_append_double (string, f[5]);
+      g_string_append (string, ", ");
+      string_append_double (string, f[12]);
+      g_string_append (string, ", ");
+      string_append_double (string, f[13]);
+      g_string_append (string, ")");
+    }
+  else
+    {
+      g_string_append (string, "matrix3d(");
+      graphene_matrix_to_float (&self->matrix, f);
+      for (i = 0; i < 16; i++)
+        {
+          if (i > 0)
+            g_string_append (string, ", ");
+          string_append_double (string, f[i]);
+        }
+      g_string_append (string, ")");
     }
-  g_string_append (string, ")");
 }
 
 static GskTransform *
@@ -469,6 +489,9 @@ gsk_transform_matrix_with_category (GskTransform            *next,
  *
  * Multiplies @next with the given @matrix.
  *
+ * This function consumes @next. Use [method@Gsk.Transform.ref] first
+ * if you want to keep it around.
+ *
  * Returns: The new transform
  **/
 GskTransform *
@@ -623,6 +646,9 @@ static const GskTransformClass GSK_TRANSLATE_TRANSFORM_CLASS =
  *
  * Translates @next in 2-dimensional space by @point.
  *
+ * This function consumes @next. Use [method@Gsk.Transform.ref] first
+ * if you want to keep it around.
+ *
  * Returns: (nullable): The new transform
  **/
 GskTransform *
@@ -643,6 +669,9 @@ gsk_transform_translate (GskTransform           *next,
  *
  * Translates @next by @point.
  *
+ * This function consumes @next. Use [method@Gsk.Transform.ref] first
+ * if you want to keep it around.
+ *
  * Returns: (nullable): The new transform
  **/
 GskTransform *
@@ -860,6 +889,9 @@ normalize_angle (float angle)
  * Rotates @next @angle degrees in 2D - or in 3D-speak, around the Z axis.
  * The rotation happens around the origin point of (0, 0).
  *
+ * This function consumes @next. Use [method@Gsk.Transform.ref] first
+ * if you want to keep it around.
+ *
  * Returns: (nullable): The new transform
  */
 GskTransform *
@@ -988,6 +1020,9 @@ static const GskTransformClass GSK_ROTATE3D_TRANSFORM_CLASS =
  *
  * For a rotation in 2D space, use [method@Gsk.Transform.rotate]
  *
+ * This function consumes @next. Use [method@Gsk.Transform.ref] first
+ * if you want to keep it around.
+ *
  * Returns: (nullable): The new transform
  */
 GskTransform *
@@ -1164,6 +1199,9 @@ static const GskTransformClass GSK_SKEW_TRANSFORM_CLASS =
  *
  * Applies a skew transform.
  *
+ * This function consumes @next. Use [method@Gsk.Transform.ref] first
+ * if you want to keep it around.
+ *
  * Returns: (nullable): The new transform
  *
  * Since: 4.6
@@ -1336,6 +1374,9 @@ static const GskTransformClass GSK_SCALE_TRANSFORM_CLASS =
  *
  * Use [method@Gsk.Transform.scale_3d] to scale in all 3 dimensions.
  *
+ * This function consumes @next. Use [method@Gsk.Transform.ref] first
+ * if you want to keep it around.
+ *
  * Returns: (nullable): The new transform
  **/
 GskTransform *
@@ -1355,6 +1396,9 @@ gsk_transform_scale (GskTransform *next,
  *
  * Scales @next by the given factors.
  *
+ * This function consumes @next. Use [method@Gsk.Transform.ref] first
+ * if you want to keep it around.
+ *
  * Returns: (nullable): The new transform
  **/
 GskTransform *
@@ -1490,6 +1534,9 @@ static const GskTransformClass GSK_PERSPECTIVE_TRANSFORM_CLASS =
  * those with negative Z values towards the origin. Points
  * on the z=0 plane are unchanged.
  *
+ * This function consumes @next. Use [method@Gsk.Transform.ref] first
+ * if you want to keep it around.
+ *
  * Returns: The new transform
  */
 GskTransform *
@@ -1899,6 +1946,9 @@ gsk_transform_to_translate (GskTransform *self,
  *
  * Applies all the operations from @other to @next.
  *
+ * This function consumes @next. Use [method@Gsk.Transform.ref] first
+ * if you want to keep it around.
+ *
  * Returns: (nullable): The new transform
  */
 GskTransform *
@@ -1935,6 +1985,9 @@ gsk_transform_transform (GskTransform *next,
  * between those cases, you should check @self is not %NULL
  * before calling this function.
  *
+ * This function consumes @self. Use [method@Gsk.Transform.ref] first
+ * if you want to keep it around.
+ *
  * Returns: (nullable): The inverted transform
  */
 GskTransform *
@@ -2003,7 +2056,7 @@ GskTransformCategory
   return self->category;
 }
 
-/*
+/**
  * gsk_transform_new: (constructor):
  *
  * Creates a new identity transform.
