@@ -512,6 +512,8 @@ gtk_combo_box_class_init (GtkComboBoxClass *klass)
    * This is an [keybinding signal](class.SignalAction.html).
    *
    * The default bindings for this signal are Alt+Up and Escape.
+   *
+   * Returns: whether the combo box was popped down
    */
   combo_box_signals[POPDOWN] =
     g_signal_new_class_handler (I_("popdown"),
@@ -3033,7 +3035,7 @@ gtk_combo_box_set_child (GtkComboBox *combo_box,
   GtkComboBoxPrivate *priv = gtk_combo_box_get_instance_private (combo_box);
 
   g_return_if_fail (GTK_IS_COMBO_BOX (combo_box));
-  g_return_if_fail (child == NULL || GTK_IS_WIDGET (child));
+  g_return_if_fail (child == NULL || gtk_widget_get_parent (child) == NULL);
 
   if (priv->child)
     gtk_combo_box_remove (combo_box, priv->child);
