@@ -31,6 +31,7 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 
 typedef struct {
   GtkWindow *parent;
+  char *handle;
   GAppLaunchContext *context;
   char *uri;
   GTask *task;
@@ -39,9 +40,10 @@ typedef struct {
 static void
 gtk_show_uri_data_free (GtkShowUriData *data)
 {
-  if (data->parent)
-    gtk_window_unexport_handle (data->parent);
+  if (data->parent && data->handle)
+    gtk_window_unexport_handle (data->parent, data->handle);
   g_clear_object (&data->parent);
+  g_free (data->handle);
   g_clear_object (&data->context);
   g_free (data->uri);
   g_clear_object (&data->task);
@@ -72,7 +74,10 @@ window_handle_exported (GtkWindow  *window,
   GtkShowUriData *data = user_data;
 
   if (handle)
-    g_app_launch_context_setenv (data->context, "PARENT_WINDOW_ID", handle);
+    {
+      g_app_launch_context_setenv (data->context, "PARENT_WINDOW_ID", handle);
+      data->handle = g_strdup (handle);
+    }
 
   g_app_info_launch_default_for_uri_async (data->uri,
                                            data->context,
@@ -94,7 +99,6 @@ window_handle_exported (GtkWindow  *window,
  * a given uri.
  *
  * The @callback will be called when the launch is completed.
- * It should call gtk_show_uri_full_finish() to obtain the result.
  *
  * This is the recommended call to be used as it passes information
  * necessary for sandbox helpers to parent their dialogs properly.
@@ -148,8 +152,8 @@ gtk_show_uri_full (GtkWindow           *parent,
  * Returns: %TRUE if the URI was shown successfully.
  *   Otherwise, %FALSE is returned and @error is set
  *
- * Deprecated: 4.10: Use [method@Gtk.FileLauncher.launch_finish] or
- *   [method@Gtk.UriLauncher.launch_finish] instead
+ * Deprecated: 4.10: Use [method@Gtk.FileLauncher.launch] or
+ *   [method@Gtk.UriLauncher.launch] instead
  */
 gboolean
 gtk_show_uri_full_finish (GtkWindow     *parent,
