@@ -789,9 +789,7 @@ gtk_style_context_resolve_color (GtkStyleContext    *context,
   if (gtk_css_node_get_parent (priv->cssnode))
     ctx.parent_style = gtk_css_node_get_style (gtk_css_node_get_parent (priv->cssnode));
 
-  val = gtk_css_color_value_resolve (color,
-                                     &ctx,
-                                     _gtk_style_context_peek_property (context, GTK_CSS_PROPERTY_COLOR));
+  val = gtk_css_value_resolve (color, &ctx, _gtk_style_context_peek_property (context, GTK_CSS_PROPERTY_COLOR));
 
   if (val == NULL)
     return FALSE;
