@@ -228,7 +228,11 @@ gtk_application_load_resources (GtkApplication *application)
     path = g_strconcat (base_path, optional_slash, "gtk/help-overlay.ui", NULL);
     if (g_resources_get_info (path, G_RESOURCE_LOOKUP_FLAGS_NONE, NULL, NULL, NULL))
       {
+#ifdef __APPLE__
+        const char * const accels[] = { "<Meta>question", NULL };
+#else
         const char * const accels[] = { "<Control>question", NULL };
+#endif
 
         priv->help_overlay_path = path;
         gtk_application_set_accels_for_action (application, "win.show-help-overlay", accels);
@@ -257,14 +261,14 @@ gtk_application_startup (GApplication *g_application)
 
   before2 = GDK_PROFILER_CURRENT_TIME;
   gtk_init ();
-  gdk_profiler_end_mark (before2, "gtk init", NULL);
+  gdk_profiler_end_mark (before2, "gtk_init", NULL);
 
   priv->impl = gtk_application_impl_new (application, gdk_display_get_default ());
   gtk_application_impl_startup (priv->impl, priv->register_session);
 
   gtk_application_load_resources (application);
 
-  gdk_profiler_end_mark (before, "gtk application startup", NULL);
+  gdk_profiler_end_mark (before, "Application startup", NULL);
 }
 
 static void
@@ -990,11 +994,13 @@ GtkActionMuxer *
 gtk_application_get_parent_muxer_for_window (GtkWindow *window)
 {
   GtkApplication *application = gtk_window_get_application (window);
-  GtkApplicationPrivate *priv = gtk_application_get_instance_private (application);
+  GtkApplicationPrivate *priv;
 
   if (!application)
     return NULL;
 
+  priv = gtk_application_get_instance_private (application);
+
   return priv->muxer;
 }
 
