@@ -29,7 +29,6 @@
 #include "gtkactionhelperprivate.h"
 #include "gtkboxlayout.h"
 #include "gtkbuiltiniconprivate.h"
-#include "gtkcssnumbervalueprivate.h"
 #include "gtkgestureclick.h"
 #include <glib/gi18n-lib.h>
 #include "gtklabel.h"
@@ -37,7 +36,6 @@
 #include "gtkshortcuttrigger.h"
 #include "gtkcssnodeprivate.h"
 #include "gtkwidgetprivate.h"
-#include "gtkmodelbuttonprivate.h"
 
 /**
  * GtkCheckButton:
@@ -82,6 +80,12 @@
  * `GAction` with a target for each button. Using the `toggled` signals to keep
  * track of the group changes and state is discouraged.
  *
+ * # Shortcuts and Gestures
+ *
+ * `GtkCheckButton` supports the following keyboard shortcuts:
+ *
+ * - <kbd>␣</kbd> or <kbd>Enter</kbd> activates the button.
+ *
  * # CSS nodes
  *
  * ```
@@ -483,16 +487,15 @@ gtk_check_button_focus (GtkWidget         *widget,
             }
         }
 
+      g_ptr_array_free (child_array, TRUE);
 
-      if (new_focus)
+      if (new_focus && new_focus != widget)
         {
           gtk_widget_grab_focus (new_focus);
           gtk_widget_activate (new_focus);
+          return TRUE;
         }
-
-      g_ptr_array_free (child_array, TRUE);
-
-      return TRUE;
+      return FALSE;
     }
   else
     {
@@ -675,6 +678,9 @@ gtk_check_button_class_init (GtkCheckButtonClass *class)
    * Applications should never connect to this signal, but use the
    * [signal@Gtk.CheckButton::toggled] signal.
    *
+   * The default bindings for this signal are all forms of the
+   * <kbd>␣</kbd> and <kbd>Enter</kbd> keys.
+   *
    * Since: 4.2
    */
   signals[ACTIVATE] =
@@ -1006,7 +1012,7 @@ gtk_check_button_set_group (GtkCheckButton *self,
                             GtkCheckButton *group)
 {
   GtkCheckButtonPrivate *priv = gtk_check_button_get_instance_private (self);
-  GtkCheckButtonPrivate *group_priv = gtk_check_button_get_instance_private (group);
+  GtkCheckButtonPrivate *group_priv;
 
   g_return_if_fail (GTK_IS_CHECK_BUTTON (self));
   g_return_if_fail (self != group);
@@ -1037,6 +1043,8 @@ gtk_check_button_set_group (GtkCheckButton *self,
   if (priv->group_next == group)
     return;
 
+  group_priv = gtk_check_button_get_instance_private (group);
+
   priv->group_prev = NULL;
   if (group_priv->group_prev)
     {
@@ -1129,8 +1137,13 @@ void
 gtk_check_button_set_child (GtkCheckButton *button,
                             GtkWidget      *child)
 {
+  GtkCheckButtonPrivate *priv = gtk_check_button_get_instance_private (button);
+
   g_return_if_fail (GTK_IS_CHECK_BUTTON (button));
-  g_return_if_fail (child == NULL || GTK_IS_WIDGET (child));
+  g_return_if_fail (child == NULL || priv->child == child || gtk_widget_get_parent (child) == NULL);
+
+  if (priv->child == child)
+    return;
 
   g_object_freeze_notify (G_OBJECT (button));
 
