@@ -861,6 +861,8 @@ gtk_column_view_class_init (GtkColumnViewClass *klass)
    *
    * The factory used for configuring rows.
    *
+   * The factory must be for configuring [class@Gtk.ColumnViewRow] objects.
+   *
    * Since: 4.12
    */
   properties[PROP_ROW_FACTORY] =
@@ -926,6 +928,8 @@ gtk_column_view_class_init (GtkColumnViewClass *klass)
    *
    * Factory for creating header widgets.
    *
+   * The factory must be for configuring [class@Gtk.ListHeader] objects.
+   *
    * Since: 4.12
    */
   properties[PROP_HEADER_FACTORY] =
@@ -1798,6 +1802,8 @@ gtk_column_view_scroll_to_column (GtkColumnView       *self,
                                                        gtk_adjustment_get_page_size (self->hadjustment));
 
   gtk_adjustment_set_value (self->hadjustment, new_value);
+
+  g_clear_pointer (&scroll_info, gtk_scroll_info_unref);
 }
 
 void
@@ -2182,7 +2188,8 @@ gtk_column_view_set_header_factory (GtkColumnView      *self,
 /**
  * gtk_column_view_scroll_to:
  * @self: The columnview to scroll in
- * @pos: position of the item
+ * @pos: position of the item. Must be less than the number of
+ *   items in the view.
  * @column: (nullable) (transfer none): The column to scroll to
  *   or %NULL to not scroll columns.
  * @flags: actions to perform
@@ -2205,6 +2212,7 @@ gtk_column_view_scroll_to (GtkColumnView       *self,
                            GtkScrollInfo       *scroll)
 {
   g_return_if_fail (GTK_IS_COLUMN_VIEW (self));
+  g_return_if_fail (pos < gtk_list_base_get_n_items (GTK_LIST_BASE (self->listview)));
   g_return_if_fail (column == NULL || GTK_IS_COLUMN_VIEW_COLUMN (column));
   if (column)
     {
@@ -2214,9 +2222,14 @@ gtk_column_view_scroll_to (GtkColumnView       *self,
   if (column && (flags & GTK_LIST_SCROLL_FOCUS))
     gtk_column_view_set_focus_column (self, column, FALSE);
 
-  gtk_list_view_scroll_to (self->listview, pos, flags, scroll);
+  gtk_list_view_scroll_to (self->listview,
+                           pos,
+                           flags,
+                           scroll ? gtk_scroll_info_ref (scroll) : NULL);
 
   if (column)
     gtk_column_view_scroll_to_column (self, column, scroll);
+  else
+    g_clear_pointer (&scroll, gtk_scroll_info_unref);
 }
 
