@@ -29,10 +29,10 @@ struct _GtkCssTransition
   GtkStyleAnimation parent;
 
   guint               property;
+  guint               finished;
   GtkCssValue        *start;
   GtkCssValue        *ease;
   GtkProgressTracker  tracker;
-  guint               finished;
 };
 
 
@@ -57,22 +57,22 @@ gtk_css_transition_apply_values (GtkStyleAnimation   *style_animation,
   state = gtk_progress_tracker_get_state (&transition->tracker);
 
   if (state == GTK_PROGRESS_STATE_BEFORE)
-    value = _gtk_css_value_ref (transition->start);
+    value = gtk_css_value_ref (transition->start);
   else if (state == GTK_PROGRESS_STATE_DURING)
     {
       progress = gtk_progress_tracker_get_progress (&transition->tracker, FALSE);
       progress = _gtk_css_ease_value_transform (transition->ease, progress);
 
-      value = _gtk_css_value_transition (transition->start,
-                                         end,
-                                         transition->property,
-                                         progress);
+      value = gtk_css_value_transition (transition->start,
+                                        end,
+                                        transition->property,
+                                        progress);
     }
   else
     return;
 
   if (value == NULL)
-    value = _gtk_css_value_ref (end);
+    value = gtk_css_value_ref (end);
 
   gtk_css_animated_style_set_animated_value (style, transition->property, value);
 }
@@ -100,8 +100,7 @@ gtk_css_transition_free (GtkStyleAnimation *animation)
 
   gtk_css_value_unref (self->start);
   gtk_css_value_unref (self->ease);
-
-  g_slice_free (GtkCssTransition, self);
+  g_free (self);
 }
 
 static const GtkStyleAnimationClass GTK_CSS_TRANSITION_CLASS = {
@@ -120,13 +119,13 @@ gtk_css_transition_advance (GtkStyleAnimation    *style_animation,
   GtkCssTransition *source = (GtkCssTransition *)style_animation;
   GtkCssTransition *transition;
 
-  transition = g_slice_alloc (sizeof (GtkCssTransition));
+  transition = g_new (GtkCssTransition, 1);
   transition->parent.class = &GTK_CSS_TRANSITION_CLASS;
   transition->parent.ref_count = 1;
 
   transition->property = source->property;
-  transition->start = _gtk_css_value_ref (source->start);
-  transition->ease = _gtk_css_value_ref (source->ease);
+  transition->start = gtk_css_value_ref (source->start);
+  transition->ease = gtk_css_value_ref (source->ease);
 
   gtk_progress_tracker_init_copy (&source->tracker, &transition->tracker);
   gtk_progress_tracker_advance_frame (&transition->tracker, timestamp);
@@ -147,13 +146,13 @@ _gtk_css_transition_new (guint        property,
   g_return_val_if_fail (start != NULL, NULL);
   g_return_val_if_fail (ease != NULL, NULL);
 
-  transition = g_slice_alloc (sizeof (GtkCssTransition));
+  transition = g_new (GtkCssTransition, 1);
   transition->parent.class = &GTK_CSS_TRANSITION_CLASS;
   transition->parent.ref_count = 1;
 
   transition->property = property;
-  transition->start = _gtk_css_value_ref (start);
-  transition->ease = _gtk_css_value_ref (ease);
+  transition->start = gtk_css_value_ref (start);
+  transition->ease = gtk_css_value_ref (ease);
   gtk_progress_tracker_start (&transition->tracker, duration_us, delay_us, 1.0);
   gtk_progress_tracker_advance_frame (&transition->tracker, timestamp);
   transition->finished = gtk_progress_tracker_get_state (&transition->tracker) == GTK_PROGRESS_STATE_AFTER;
