@@ -48,6 +48,19 @@
  * `GtkEmojiChooser` emits the [signal@Gtk.EmojiChooser::emoji-picked]
  * signal when an Emoji is selected.
  *
+ * # Shortcuts and Gestures
+ *
+ * `GtkEmojiChooser` supports the following keyboard shortcuts:
+ *
+ * - <kbd>Ctrl</kbd>+<kbd>N</kbd> scrolls th the next section.
+ * - <kbd>Ctrl</kbd>+<kbd>P</kbd> scrolls th the previous section.
+ *
+ * # Actions
+ *
+ * `GtkEmojiChooser` defines a set of built-in actions:
+ *
+ * - `scroll.section` scrolls to the next or previous section.
+ *
  * # CSS nodes
  *
  * ```
@@ -449,7 +462,7 @@ static gboolean
 has_variations (GVariant *emoji_data)
 {
   GVariant *codes;
-  int i;
+  gsize i;
   gboolean has_variations;
 
   has_variations = FALSE;
@@ -458,7 +471,7 @@ has_variations (GVariant *emoji_data)
     {
       gunichar code;
       g_variant_get_child (codes, i, "u", &code);
-      if (code == 0)
+      if (code == 0 || code == 0x1f3fb)
         {
           has_variations = TRUE;
           break;
@@ -571,15 +584,14 @@ add_emoji (GtkWidget    *box,
     {
       g_variant_get_child (codes, i, "u", &code);
       if (code == 0)
+        code = modifier != 0 ? modifier : 0xfe0f;
+      if (code == 0x1f3fb)
         code = modifier;
       if (code != 0)
         p += g_unichar_to_utf8 (code, p);
     }
   g_variant_unref (codes);
 
-  if (code != 0xFE0F && code != 0xFE0E)
-    p += g_unichar_to_utf8 (0xFE0F, p); /* Append a variation selector, if there isn't one already */
-
   p[0] = 0;
 
   label = gtk_label_new (text);
