@@ -37,10 +37,7 @@
  * should be modal.
  *
  * The dialog is shown with [method@Gtk.FileDialog.open],
- * [method@Gtk.FileDialog.save], etc. These APIs follow the
- * GIO async pattern, and the result can be obtained by calling
- * the corresponding finish function, for example
- * [method@Gtk.FileDialog.open_finish].
+ * [method@Gtk.FileDialog.save], etc.
  *
  * Since: 4.10
  */
@@ -693,7 +690,7 @@ gtk_file_dialog_set_initial_file (GtkFileDialog *self,
     {
       GFile *folder;
       GFileInfo *info;
-   
+
       if (self->initial_file && g_file_equal (self->initial_file, file))
         return;
 
@@ -887,11 +884,15 @@ finish_file_op (GtkFileDialog  *self,
   files = g_task_propagate_pointer (task, error);
   if (files)
     {
-      GFile *file;
+      GFile *file = NULL;
 
-      g_assert (g_list_model_get_n_items (files) == 1);
+      if (g_list_model_get_n_items (files) > 0)
+        file = g_list_model_get_item (files, 0);
+      else
+        g_set_error_literal (error,
+                             GTK_DIALOG_ERROR, GTK_DIALOG_ERROR_FAILED,
+                             "No file selected");
 
-      file = g_list_model_get_item (files, 0);
       g_object_unref (files);
 
       return file;
@@ -923,8 +924,6 @@ finish_multiple_files_op (GtkFileDialog  *self,
  * presenting a file chooser dialog to the user.
  *
  * The @callback will be called when the dialog is dismissed.
- * It should call [method@Gtk.FileDialog.open_finish]
- * to obtain the result.
  *
  * Since: 4.10
  */
@@ -997,8 +996,6 @@ gtk_file_dialog_open_finish (GtkFileDialog   *self,
  * will be in the directory [property@Gtk.FileDialog:initial-folder].
  *
  * The @callback will be called when the dialog is dismissed.
- * It should call [method@Gtk.FileDialog.select_folder_finish]
- * to obtain the result.
  *
  * Since: 4.10
  */
@@ -1067,8 +1064,6 @@ gtk_file_dialog_select_folder_finish (GtkFileDialog  *self,
  * presenting a file chooser dialog to the user.
  *
  * The @callback will be called when the dialog is dismissed.
- * It should call [method@Gtk.FileDialog.save_finish]
- * to obtain the result.
  *
  * Since: 4.10
  */
@@ -1140,8 +1135,6 @@ gtk_file_dialog_save_finish (GtkFileDialog   *self,
  * [property@Gtk.FileDialog:initial-folder].
  *
  * The @callback will be called when the dialog is dismissed.
- * It should call [method@Gtk.FileDialog.open_multiple_finish]
- * to obtain the result.
  *
  * Since: 4.10
  */
@@ -1214,8 +1207,6 @@ gtk_file_dialog_open_multiple_finish (GtkFileDialog   *self,
  * [property@Gtk.FileDialog:initial-folder].
  *
  * The @callback will be called when the dialog is dismissed.
- * It should call [method@Gtk.FileDialog.select_multiple_folders_finish]
- * to obtain the result.
  *
  * Since: 4.10
  */
@@ -1277,6 +1268,8 @@ gtk_file_dialog_select_multiple_folders_finish (GtkFileDialog   *self,
  * gtk_file_dialog_get_accept_label:
  * @self: a `GtkFileDialog`
  *
+ * Retrieves the text used by the dialog on its accept button.
+ *
  * Returns: (nullable): the label shown on the file chooser's accept button.
  *
  * Since: 4.10
