@@ -21,14 +21,14 @@
 
 #include "gtkfilter.h"
 
-#include "gtkintl.h"
 #include "gtktypebuiltins.h"
+#include "gtkprivate.h"
 
 /**
  * GtkFilter:
  *
  * A `GtkFilter` object describes the filtering to be performed by a
- * `GtkFilterListModel`.
+ * [class@Gtk.FilterListModel].
  *
  * The model will use the filter to determine if it should include items
  * or not by calling [method@Gtk.Filter.match] for each item and only
@@ -173,7 +173,7 @@ gtk_filter_get_strictness (GtkFilter *self)
  * be changed, but only some. Refer to the [enum@Gtk.FilterChange]
  * documentation for details.
  *
- * This function is intended for implementors of `GtkFilter`
+ * This function is intended for implementers of `GtkFilter`
  * subclasses and should not be called from other functions.
  */
 void
