@@ -37,9 +37,7 @@
  * should be modal.
  *
  * The dialog is shown with the [method@Gtk.FontDialog.choose_font]
- * function or its variants. This API follows the GIO async pattern,
- * and the result can be obtained by calling the corresponding
- * finish function, such as [method@Gtk.FontDialog.choose_font_finish].
+ * function or its variants.
  *
  * See [class@Gtk.FontDialogButton] for a convenient control
  * that uses `GtkFontDialog` and presents the results.
@@ -561,9 +559,10 @@ response_cb (GTask *task,
         }
     }
   else if (response == GTK_RESPONSE_CLOSE)
-    g_task_return_new_error (task, GTK_DIALOG_ERROR, GTK_DIALOG_ERROR_ABORTED, "Aborted by application");
-  else if (response == GTK_RESPONSE_CANCEL)
-  g_task_return_new_error (task, GTK_DIALOG_ERROR, GTK_DIALOG_ERROR_CANCELLED, "Cancelled by user");
+    g_task_return_new_error (task, GTK_DIALOG_ERROR, GTK_DIALOG_ERROR_CANCELLED, "Cancelled by application");
+  else if (response == GTK_RESPONSE_CANCEL ||
+           response == GTK_RESPONSE_DELETE_EVENT)
+    g_task_return_new_error (task, GTK_DIALOG_ERROR, GTK_DIALOG_ERROR_DISMISSED, "Dismissed by user");
   else
     g_task_return_new_error (task, GTK_DIALOG_ERROR, GTK_DIALOG_ERROR_FAILED, "Unknown failure (%d)", response);
 
@@ -596,6 +595,7 @@ create_font_chooser (GtkFontDialog        *self,
 
   window = gtk_font_chooser_dialog_new (title, parent);
   gtk_font_chooser_set_level (GTK_FONT_CHOOSER (window), level);
+  gtk_window_set_modal (GTK_WINDOW (window), TRUE);
   if (self->language)
     gtk_font_chooser_set_language (GTK_FONT_CHOOSER (window),
                                    pango_language_to_string (self->language));
@@ -625,10 +625,6 @@ G_GNUC_END_IGNORE_DEPRECATIONS
  * This function initiates a font selection operation by
  * presenting a dialog to the user for selecting a font family.
  *
- * The @callback will be called when the dialog is dismissed.
- * It should call [method@Gtk.FontDialog.choose_family_finish]
- * to obtain the result.
- *
  * Since: 4.10
  */
 void
@@ -657,6 +653,7 @@ gtk_font_dialog_choose_family (GtkFontDialog        *self,
   g_clear_pointer (&desc, pango_font_description_free);
 
   task = g_task_new (self, cancellable, callback, user_data);
+  g_task_set_check_cancellable (task, FALSE);
   g_task_set_source_tag (task, gtk_font_dialog_choose_family);
   g_task_set_task_data (task, window, (GDestroyNotify) gtk_window_destroy);
 
@@ -672,7 +669,7 @@ gtk_font_dialog_choose_family (GtkFontDialog        *self,
  * gtk_font_dialog_choose_family_finish:
  * @self: a `GtkFontDialog`
  * @result: a `GAsyncResult`
- * @error: return location for an error
+ * @error: return location for a [enum@Gtk.DialogError] error
  *
  * Finishes the [method@Gtk.FontDialog.choose_family] call
  * and returns the resulting family.
@@ -694,6 +691,9 @@ gtk_font_dialog_choose_family_finish (GtkFontDialog  *self,
   g_return_val_if_fail (g_task_is_valid (result, self), NULL);
   g_return_val_if_fail (g_task_get_source_tag (G_TASK (result)) == gtk_font_dialog_choose_family, NULL);
 
+  /* Destroy the dialog window not to be bound to GTask lifecycle */
+  g_task_set_task_data (G_TASK (result), NULL, NULL);
+
   return g_task_propagate_pointer (G_TASK (result), error);
 }
 
@@ -710,10 +710,6 @@ gtk_font_dialog_choose_family_finish (GtkFontDialog  *self,
  * presenting a dialog to the user for selecting a font face
  * (i.e. a font family and style, but not a specific font size).
  *
- * The @callback will be called when the dialog is dismissed.
- * It should call [method@Gtk.FontDialog.choose_face_finish]
- * to obtain the result.
- *
  * Since: 4.10
  */
 void
@@ -740,6 +736,7 @@ gtk_font_dialog_choose_face (GtkFontDialog       *self,
   g_clear_pointer (&desc, pango_font_description_free);
 
   task = g_task_new (self, cancellable, callback, user_data);
+  g_task_set_check_cancellable (task, FALSE);
   g_task_set_source_tag (task, gtk_font_dialog_choose_face);
   g_task_set_task_data (task, window, (GDestroyNotify) gtk_window_destroy);
 
@@ -755,7 +752,7 @@ gtk_font_dialog_choose_face (GtkFontDialog       *self,
  * gtk_font_dialog_choose_face_finish:
  * @self: a `GtkFontDialog`
  * @result: a `GAsyncResult`
- * @error: return location for an error
+ * @error: return location for a [enum@Gtk.DialogError] error
  *
  * Finishes the [method@Gtk.FontDialog.choose_face] call
  * and returns the resulting font face.
@@ -773,7 +770,10 @@ gtk_font_dialog_choose_face_finish (GtkFontDialog  *self,
   g_return_val_if_fail (g_task_is_valid (result, self), NULL);
   g_return_val_if_fail (g_task_get_source_tag (G_TASK (result)) == gtk_font_dialog_choose_face, NULL);
 
-  return g_task_propagate_pointer (G_TASK (result), NULL);
+  /* Destroy the dialog window not to be bound to GTask lifecycle */
+  g_task_set_task_data (G_TASK (result), NULL, NULL);
+
+  return g_task_propagate_pointer (G_TASK (result), error);
 }
 
 /**
@@ -788,10 +788,6 @@ gtk_font_dialog_choose_face_finish (GtkFontDialog  *self,
  * This function initiates a font selection operation by
  * presenting a dialog to the user for selecting a font.
  *
- * The @callback will be called when the dialog is dismissed.
- * It should call [method@Gtk.FontDialog.choose_font_finish]
- * to obtain the result.
- *
  * If you want to let the user select font features as well,
  * use [method@Gtk.FontDialog.choose_font_and_features] instead.
  *
@@ -817,6 +813,7 @@ gtk_font_dialog_choose_font (GtkFontDialog        *self,
                                 GTK_FONT_CHOOSER_LEVEL_VARIATIONS);
 
   task = g_task_new (self, cancellable, callback, user_data);
+  g_task_set_check_cancellable (task, FALSE);
   g_task_set_source_tag (task, gtk_font_dialog_choose_font);
   g_task_set_task_data (task, window, (GDestroyNotify) gtk_window_destroy);
 
@@ -832,7 +829,7 @@ gtk_font_dialog_choose_font (GtkFontDialog        *self,
  * gtk_font_dialog_choose_font_finish:
  * @self: a `GtkFontDialog`
  * @result: a `GAsyncResult`
- * @error: return location for an error
+ * @error: return location for a [enum@Gtk.DialogError] error
  *
  * Finishes the [method@Gtk.FontDialog.choose_font] call
  * and returns the resulting font description.
@@ -850,7 +847,10 @@ gtk_font_dialog_choose_font_finish (GtkFontDialog  *self,
   g_return_val_if_fail (g_task_is_valid (result, self), NULL);
   g_return_val_if_fail (g_task_get_source_tag (G_TASK (result)) == gtk_font_dialog_choose_font, NULL);
 
-  return g_task_propagate_pointer (G_TASK (result), NULL);
+  /* Destroy the dialog window not to be bound to GTask lifecycle */
+  g_task_set_task_data (G_TASK (result), NULL, NULL);
+
+  return g_task_propagate_pointer (G_TASK (result), error);
 }
 
 /**
@@ -869,10 +869,6 @@ gtk_font_dialog_choose_font_finish (GtkFontDialog  *self,
  * Font features affect how the font is rendered, for example
  * enabling glyph variants or ligatures.
  *
- * The @callback will be called when the dialog is dismissed.
- * It should call [method@Gtk.FontDialog.choose_font_and_features_finish]
- * to obtain the result.
- *
  * Since: 4.10
  */
 void
@@ -896,6 +892,7 @@ gtk_font_dialog_choose_font_and_features (GtkFontDialog        *self,
                                 GTK_FONT_CHOOSER_LEVEL_FEATURES);
 
   task = g_task_new (self, cancellable, callback, user_data);
+  g_task_set_check_cancellable (task, FALSE);
   g_task_set_source_tag (task, gtk_font_dialog_choose_font_and_features);
   g_task_set_task_data (task, window, (GDestroyNotify) gtk_window_destroy);
 
@@ -911,10 +908,10 @@ gtk_font_dialog_choose_font_and_features (GtkFontDialog        *self,
  * gtk_font_dialog_choose_font_and_features_finish:
  * @self: a `GtkFontDialog`
  * @result: a `GAsyncResult`
- * @font_desc: (out caller-allocates): return location for font description
- * @font_features: (out caller-allocates): return location for font features
- * @language: (out caller-allocates): return location for the language
- * @error: return location for an error
+ * @font_desc: (out): return location for font description
+ * @font_features: (out): return location for font features
+ * @language: (out): return location for the language
+ * @error: return location for a [enum@Gtk.DialogError] error
  *
  * Finishes the [method@Gtk.FontDialog.choose_font_and_features]
  * call and returns the resulting font description and font features.
@@ -938,6 +935,8 @@ gtk_font_dialog_choose_font_and_features_finish (GtkFontDialog         *self,
   g_return_val_if_fail (g_task_is_valid (result, self), FALSE);
   g_return_val_if_fail (g_task_get_source_tag (G_TASK (result)) == gtk_font_dialog_choose_font_and_features, FALSE);
 
+  /* Destroy the dialog window not to be bound to GTask lifecycle */
+  g_task_set_task_data (G_TASK (result), NULL, NULL);
   font_result = g_task_propagate_pointer (G_TASK (result), error);
 
   if (font_result)
