@@ -49,10 +49,11 @@ gtk_theming_background_snapshot_color (GtkCssBoxes       *boxes,
                                        const GdkRGBA     *bg_color,
                                        guint              n_bg_values)
 {
+  GtkCssStyle *style = boxes->style;
   const GskRoundedRect *box;
   GtkCssArea clip;
 
-  clip = _gtk_css_area_value_get (_gtk_css_array_value_get_nth (boxes->style->background->background_clip, n_bg_values - 1));
+  clip = _gtk_css_area_value_get (_gtk_css_array_value_get_nth (style->background->background_clip, n_bg_values - 1));
   box = gtk_css_boxes_get_box (boxes, clip);
 
   if (gsk_rounded_rect_is_rectilinear (box))
@@ -76,7 +77,7 @@ gtk_theming_background_snapshot_layer (GtkCssBoxes *bg,
                                        guint        idx,
                                        GtkSnapshot *snapshot)
 {
-  GtkCssBackgroundValues *background = bg->style->background;
+  GtkCssStyle *style = bg->style;
   GtkCssRepeatStyle hrepeat, vrepeat;
   const GtkCssValue *pos, *repeat;
   GtkCssImage *image;
@@ -85,17 +86,17 @@ gtk_theming_background_snapshot_layer (GtkCssBoxes *bg,
   double width, height;
   double x, y;
 
-  image = _gtk_css_image_value_get_image (_gtk_css_array_value_get_nth (background->background_image, idx));
+  image = _gtk_css_image_value_get_image (_gtk_css_array_value_get_nth (style->used->background_image, idx));
 
   if (image == NULL)
     return;
 
-  pos = _gtk_css_array_value_get_nth (background->background_position, idx);
-  repeat = _gtk_css_array_value_get_nth (background->background_repeat, idx);
+  pos = _gtk_css_array_value_get_nth (style->background->background_position, idx);
+  repeat = _gtk_css_array_value_get_nth (style->background->background_repeat, idx);
 
   origin = gtk_css_boxes_get_box (bg,
                                   _gtk_css_area_value_get (
-                                      _gtk_css_array_value_get_nth (background->background_origin, idx)));
+                                      _gtk_css_array_value_get_nth (style->background->background_origin, idx)));
 
   width = origin->bounds.size.width;
   height = origin->bounds.size.height;
@@ -105,9 +106,9 @@ gtk_theming_background_snapshot_layer (GtkCssBoxes *bg,
 
   clip = gtk_css_boxes_get_box (bg,
                                 _gtk_css_area_value_get (
-                                    _gtk_css_array_value_get_nth (background->background_clip, idx)));
+                                    _gtk_css_array_value_get_nth (style->background->background_clip, idx)));
 
-  _gtk_css_bg_size_value_compute_size (_gtk_css_array_value_get_nth (background->background_size, idx),
+  _gtk_css_bg_size_value_compute_size (_gtk_css_array_value_get_nth (style->background->background_size, idx),
                                        image,
                                        width,
                                        height,
@@ -210,27 +211,17 @@ gtk_theming_background_snapshot_layer (GtkCssBoxes *bg,
       else
         repeat_height = round (image_height);
 
+      fill_rect = clip->bounds;
       if (hrepeat == GTK_CSS_REPEAT_STYLE_NO_REPEAT)
         {
           fill_rect.origin.x = _gtk_css_position_value_get_x (pos, width - image_width);
           fill_rect.size.width = image_width;
         }
-      else
-        {
-          fill_rect.origin.x = 0;
-          fill_rect.size.width = width;
-        }
-
       if (vrepeat == GTK_CSS_REPEAT_STYLE_NO_REPEAT)
         {
           fill_rect.origin.y = _gtk_css_position_value_get_y (pos, height - image_height);
           fill_rect.size.height = image_height;
         }
-      else
-        {
-          fill_rect.origin.y = 0;
-          fill_rect.size.height = height;
-        }
 
       gtk_snapshot_push_repeat (snapshot,
                                 &fill_rect,
@@ -255,7 +246,7 @@ void
 gtk_css_style_snapshot_background (GtkCssBoxes *boxes,
                                    GtkSnapshot *snapshot)
 {
-  const GtkCssBackgroundValues *background = boxes->style->background;
+  GtkCssStyle *style = boxes->style;
   GtkCssValue *background_image;
   const GdkRGBA *bg_color;
   const GtkCssValue *box_shadow;
@@ -265,12 +256,12 @@ gtk_css_style_snapshot_background (GtkCssBoxes *boxes,
   int idx;
   guint number_of_layers;
 
-  if (background->base.type == GTK_CSS_BACKGROUND_INITIAL_VALUES)
+  if (style->background->base.type == GTK_CSS_BACKGROUND_INITIAL_VALUES)
     return;
 
-  background_image = background->background_image;
-  bg_color = gtk_css_color_value_get_rgba (background->background_color);
-  box_shadow = background->box_shadow;
+  background_image = style->used->background_image;
+  bg_color = gtk_css_color_value_get_rgba (style->used->background_color);
+  box_shadow = style->used->box_shadow;
 
   has_bg_color = !gdk_rgba_is_clear (bg_color);
   has_bg_image = _gtk_css_image_value_get_image (_gtk_css_array_value_get_nth (background_image, 0)) != NULL;
@@ -291,7 +282,7 @@ gtk_css_style_snapshot_background (GtkCssBoxes *boxes,
 
   if (has_bg_image)
     {
-      GtkCssValue *blend_modes = background->background_blend_mode;
+      GtkCssValue *blend_modes = style->background->background_blend_mode;
       GskBlendMode *blend_mode_values = g_alloca (sizeof (GskBlendMode) * number_of_layers);
 
       for (idx = number_of_layers - 1; idx >= 0; idx--)
