@@ -15,8 +15,7 @@
  * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GTK_STYLE_PROVIDER_PRIVATE_H__
-#define __GTK_STYLE_PROVIDER_PRIVATE_H__
+#pragma once
 
 #include <glib-object.h>
 #include <gtk/gtkstyleprovider.h>
@@ -53,6 +52,8 @@ struct _GtkStyleProviderInterface
                                                  const GError            *error);
   /* signal */
   void                  (* changed)             (GtkStyleProvider        *provider);
+  gboolean              (* has_section)         (GtkStyleProvider        *provider,
+                                                 GtkCssSection           *section);
 };
 
 GtkSettings *           gtk_style_provider_get_settings          (GtkStyleProvider        *provider);
@@ -72,7 +73,8 @@ void                    gtk_style_provider_changed               (GtkStyleProvid
 void                    gtk_style_provider_emit_error            (GtkStyleProvider        *provider,
                                                                   GtkCssSection           *section,
                                                                   GError                  *error);
+gboolean                gtk_style_provider_has_section           (GtkStyleProvider        *provider,
+                                                                  GtkCssSection           *section);
 
 G_END_DECLS
 
-#endif /* __GTK_STYLE_PROVIDER_PRIVATE_H__ */
