@@ -37,6 +37,7 @@
 
 #include "gdk/gdkdebugprivate.h"
 #include "gdk/gdkdisplayprivate.h"
+#include "gdk/gdkmonitorprivate.h"
 
 #include "profile_conf.h"
 
@@ -672,6 +673,7 @@ add_wayland_protocols (GdkDisplay          *display,
 
       append_wayland_protocol_row (gen, (struct wl_proxy *)d->compositor);
       append_wayland_protocol_row (gen, (struct wl_proxy *)d->shm);
+      append_wayland_protocol_row (gen, (struct wl_proxy *)d->linux_dmabuf);
       append_wayland_protocol_row (gen, (struct wl_proxy *)d->xdg_wm_base);
       append_wayland_protocol_row (gen, (struct wl_proxy *)d->zxdg_shell_v6);
       append_wayland_protocol_row (gen, (struct wl_proxy *)d->gtk_shell);
@@ -691,6 +693,8 @@ add_wayland_protocols (GdkDisplay          *display,
       append_wayland_protocol_row (gen, (struct wl_proxy *)d->xdg_activation);
       append_wayland_protocol_row (gen, (struct wl_proxy *)d->fractional_scale);
       append_wayland_protocol_row (gen, (struct wl_proxy *)d->viewporter);
+      append_wayland_protocol_row (gen, (struct wl_proxy *)d->presentation);
+      append_wayland_protocol_row (gen, (struct wl_proxy *)d->single_pixel_buffer);
     }
 }
 #endif
@@ -798,6 +802,10 @@ add_monitor (GtkInspectorGeneral *gen,
   add_label_row (gen, list, "Size", value, 10);
   g_free (value);
 
+  value = g_strdup_printf ("%.1f dpi", gdk_monitor_get_dpi (monitor));
+  add_label_row (gen, list, "Resolution", value, 10);
+  g_free (value);
+
   if (gdk_monitor_get_refresh_rate (monitor) != 0)
     {
       value = g_strdup_printf ("%.2f Hz",
