@@ -194,7 +194,7 @@ scrollable_policy (void)
   g_signal_connect (G_OBJECT (widget), "toggled",
                     G_CALLBACK (kinetic_scrolling_changed), swindow);
 
-  gtk_widget_show (window);
+  gtk_window_present (GTK_WINDOW (window));
 
   /* Popover */
   popover = gtk_popover_new ();
