@@ -123,6 +123,13 @@ test_type (gconstpointer data)
                                NULL);
       g_object_unref (list_store);
     }
+  else if (g_type_is_a (type, GDK_TYPE_TEXTURE))
+    {
+      static const guint8 pixels[4] = { 0xff, 0x00, 0x00, 0xff };
+      GBytes *bytes = g_bytes_new_static (pixels, sizeof (pixels));
+      instance = (GObject *) gdk_memory_texture_new (1, 1, GDK_MEMORY_DEFAULT, bytes, 4);
+      g_bytes_unref (bytes);
+    }
   else if (g_type_is_a (type, GSK_TYPE_GL_SHADER))
     {
       GBytes *bytes = g_bytes_new_static ("", 0);
@@ -182,6 +189,10 @@ test_type (gconstpointer data)
 	  strcmp (pspec->name, "storable-formats") == 0)
 	check = FALSE;
 
+      if (g_type_is_a (type, GDK_TYPE_DMABUF_TEXTURE_BUILDER) &&
+	  strcmp (pspec->name, "display") == 0)
+	check = FALSE;
+
       /* set in the constructor */
       if (g_type_is_a (type, GSK_TYPE_GL_SHADER) &&
 	  strcmp (pspec->name, "source") == 0)
@@ -217,6 +228,10 @@ test_type (gconstpointer data)
 	  (strcmp (pspec->name, "default-display") == 0))
 	check = FALSE;
 
+      if (g_type_is_a (type, GDK_TYPE_DISPLAY) &&
+	  (strcmp (pspec->name, "dmabuf-formats") == 0))
+	check = FALSE;
+
       if (g_type_is_a (type, GDK_TYPE_MONITOR) &&
           (strcmp (pspec->name, "geometry") == 0))
         check = FALSE;
