@@ -37,7 +37,7 @@ main_loop_quit_cb (gpointer data)
 
   g_main_context_wakeup (NULL);
 
-  g_assert (finalized);
+  g_assert_true (finalized);
   return FALSE;
 }
 
@@ -69,6 +69,13 @@ test_finalize_object (gconstpointer data)
                              NULL);
       gdk_content_formats_unref (formats);
     }
+  else if (g_type_is_a (test_type, GDK_TYPE_TEXTURE))
+    {
+      static const guint8 pixels[4] = { 0xff, 0x00, 0x00, 0xff };
+      GBytes *bytes = g_bytes_new_static (pixels, sizeof (pixels));
+      object = (GObject *) gdk_memory_texture_new (1, 1, GDK_MEMORY_DEFAULT, bytes, 4);
+      g_bytes_unref (bytes);
+    }
   else if (g_type_is_a (test_type, GSK_TYPE_GL_SHADER))
     {
       GBytes *bytes = g_bytes_new_static ("", 0);
@@ -98,7 +105,7 @@ test_finalize_object (gconstpointer data)
     }
   else
     object = g_object_new (test_type, NULL);
-  g_assert (G_IS_OBJECT (object));
+  g_assert_true (G_IS_OBJECT (object));
 
   /* Make sure we have the only reference */
   if (g_object_is_floating (object))
@@ -142,7 +149,6 @@ main (int argc, char **argv)
   const char *display, *x_r_d;
 
   /* These must be set before gtk_test_init */
-  g_setenv ("GIO_USE_VFS", "local", TRUE);
   g_setenv ("GSETTINGS_BACKEND", "memory", TRUE);
 
   /* g_test_dbus_up() helpfully clears these, so we have to re-set it */
@@ -178,7 +184,9 @@ main (int argc, char **argv)
 	  all_types[i] != GDK_TYPE_PIXBUF_LOADER &&
 	  all_types[i] != gdk_pixbuf_simple_anim_iter_get_type() &&
           !g_type_is_a (all_types[i], GTK_TYPE_SHORTCUT_TRIGGER) &&
-          !g_type_is_a (all_types[i], GTK_TYPE_SHORTCUT_ACTION))
+          !g_type_is_a (all_types[i], GTK_TYPE_SHORTCUT_ACTION) &&
+          /* can't instantiate empty stack pages */
+          all_types[i] != GTK_TYPE_STACK_PAGE)
 	{
 	  char *test_path = g_strdup_printf ("/FinalizeObject/%s", g_type_name (all_types[i]));
 
